@@ -74,17 +74,17 @@ def push_to_gkeep(args: Dict[str, Any]) -> None:
     print(" Done.")
 
     # Announce what we'll do
-    color = args["--color"] or 'White'
+    color = args["--color"] or "White"
     print(
         f"Creating a "
-        + dye(' ' + color.lower() + ' ', fg=0x000, bg=COLOR_NAME_TO_HEX_MAP[color])
+        + dye(" " + color.lower() + " ", fg=0x000, bg=COLOR_NAME_TO_HEX_MAP[color])
         + dye(f" Google Keep card with tags {', '.join(args['--tag'])}", fg=C_PRIMARY)
     )
 
     # Create the note
     note = keep.createNote(title=args["--title"], text=args["IDEA"])
     note.color = getattr(ColorValue, color)
-    note.pinned = True
+    note.pinned = args["--pin"]
 
     # Find/create all the labels
     all_tags = keep.labels()
@@ -99,8 +99,8 @@ def push_to_gkeep(args: Dict[str, Any]) -> None:
 
     # Beam it up to Google's servers
     keep.sync()
-    
+
     # Open the browser
-    if args['--open']:
+    if args["--open"]:
         url = f"https://keep.google.com/u/0/#NOTE/{note.id}"
         webbrowser.open(url)
